powered by
This function filters peaks from a k-mer histogram to find a major peak with enough support information on both sides.
filter_peaks(peaks, histo)
A data frame with filtered peaks.
A data frame containing the peaks from the histogram.
A data frame representing the k-mer histogram.
peaks <- data.frame(V1=1:20, V2=sample(1:10, 20, replace=TRUE)) histo <- data.frame(V1=1:100, V2=sample(1:10, 100, replace=TRUE)) filtered_peaks <- filter_peaks(peaks, histo) print(filtered_peaks)
Run the code above in your browser using DataLab