Learn R Programming

findGSEP (version 1.2.0)

findGSE_raw: Estimate Genome Size Using Raw K-mer Frequencies

Description

This function estimates the genome size of a species using raw k-mer frequencies.

Usage

findGSE_raw(histo = "", sizek = 0, outdir = "", exp_hom = 0, species = "")

Value

A list containing the estimated genome size and other fitting parameters.

Arguments

histo

A character string specifying the path to the histogram file.

sizek

An integer indicating the size of k used to generate the histogram.

outdir

A character string specifying the output directory. If not specify, will use tempdir() as output directory.

exp_hom

A numeric value representing the expected average k-mer coverage for the homozygous regions.

species

A character string specifying the species name.

Examples

Run this code
if (FALSE) {

histo <- "sample1.histo"
sizek <- 21
outdir <- tempdir()
exp_hom <- 200
species <- ""
fit_lists <- findGSE_raw(histo, sizek,output_dir, exp_hom, species)
}

Run the code above in your browser using DataLab